{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "Calculates the square root of a number plus numbers stored in secondary files",
            "doc": "This tool reads an integer from a file, calculates the square root of that number, and saves it to an output file. It does the same for two secondary files.",
            "requirements": [
                {
                    "dockerImageId": "secondary_sqrt_tool",
                    "dockerFile": "FROM python:3.9-slim-buster",
                    "class": "DockerRequirement"
                },
                {
                    "listing": [
                        {
                            "entryname": "sqrt.py",
                            "entry": "import math\nimport sys\n\nnumber_file_path = sys.argv[1]\nout_file_path = sys.argv[2]\n\nwith open(number_file_path) as number_file:\n    with open(out_file_path, 'w') as out_file:\n      out_file.write(str(math.sqrt(float(number_file.read()))))\n\nwith open(number_file_path + \".a\") as number_file:\n    with open(out_file_path + \".c\", 'w') as out_file:\n      out_file.write(str(math.sqrt(float(number_file.read()))))\n\nwith open(number_file_path + \".b\") as number_file:\n    with open(out_file_path + \".d\", 'w') as out_file:\n      out_file.write(str(math.sqrt(float(number_file.read()))))"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "A file with a single number in it",
                    "format": "http://edamontology.org/format_1964",
                    "secondaryFiles": [
                        {
                            "pattern": ".a",
                            "required": null
                        },
                        {
                            "pattern": ".b",
                            "required": null
                        }
                    ],
                    "id": "#secondary_sqrt_tool.cwl/number_file"
                },
                {
                    "type": "string",
                    "doc": "Name of the output file\n#Output_File=edam:format_1964",
                    "id": "#secondary_sqrt_tool.cwl/output_file"
                }
            ],
            "arguments": [
                {
                    "shellQuote": false,
                    "valueFrom": "python sqrt.py $(inputs.number_file.path) $(inputs.output_file)"
                }
            ],
            "stdout": "stdout.txt",
            "stderr": "stderr.txt",
            "id": "#secondary_sqrt_tool.cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/name": "Stephen Piccolo",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-2001-5640"
                }
            ],
            "https://schema.org/dateCreated": "2020-07-14",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_file)"
                    },
                    "doc": "Output file matching the name specified in the \"output_file\" input.",
                    "format": "http://edamontology.org/format_1964",
                    "secondaryFiles": [
                        {
                            "pattern": ".c",
                            "required": null
                        },
                        {
                            "pattern": ".d",
                            "required": null
                        }
                    ],
                    "id": "#secondary_sqrt_tool.cwl/output_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1964",
                    "id": "#secondary_sqrt_tool.cwl/standard_error",
                    "outputBinding": {
                        "glob": "stderr.txt"
                    }
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1964",
                    "id": "#secondary_sqrt_tool.cwl/standard_output",
                    "outputBinding": {
                        "glob": "stdout.txt"
                    }
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#main",
            "label": "Square root considers secondary files",
            "doc": "Calculates the square root of a number stored in a file and saves the result to an output file. It does the same for two secondary files. It then sums those values and writes the sum to a file. This demonstrates using secondary files within a workflow.",
            "inputs": [
                {
                    "id": "#main/number_file",
                    "type": "File",
                    "format": "http://edamontology.org/format_1964",
                    "secondaryFiles": [
                        {
                            "pattern": ".a",
                            "required": null
                        },
                        {
                            "pattern": ".b",
                            "required": null
                        }
                    ]
                },
                {
                    "id": "#main/output_file",
                    "type": "string"
                }
            ],
            "outputs": [
                {
                    "id": "#main/sum_files__output_file",
                    "type": "File",
                    "outputSource": "#main/sum_files/output_file"
                }
            ],
            "steps": [
                {
                    "run": "#secondary_sqrt_tool.cwl",
                    "in": [
                        {
                            "id": "#main/calc_sqrt/number_file",
                            "source": "#main/number_file"
                        },
                        {
                            "id": "#main/calc_sqrt/output_file",
                            "default": "random__kkRlosRALc"
                        }
                    ],
                    "out": [
                        "#main/calc_sqrt/output_file"
                    ],
                    "id": "#main/calc_sqrt"
                },
                {
                    "run": "#sum_files_tool.cwl",
                    "in": [
                        {
                            "id": "#main/sum_files/number_file",
                            "source": "#main/calc_sqrt/output_file"
                        },
                        {
                            "id": "#main/sum_files/output_file",
                            "source": "#main/output_file"
                        }
                    ],
                    "out": [
                        "#main/sum_files/output_file"
                    ],
                    "id": "#main/sum_files"
                }
            ],
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/name": "Stephen Piccolo",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-2001-5640"
                }
            ],
            "https://schema.org/dateCreated": "2021-03-29",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0"
        },
        {
            "class": "CommandLineTool",
            "label": "Sum numbers from 1 file and 2 secondary files",
            "doc": "Reads a number from 1 file and 2 secondary files and then saves the sum to an output file.",
            "requirements": [
                {
                    "dockerImageId": "sum_files_tool",
                    "dockerFile": "FROM python:3.9-slim-buster",
                    "class": "DockerRequirement"
                },
                {
                    "listing": [
                        {
                            "entryname": "sum.py",
                            "entry": "import math\nimport sys\n\nnumber_file_path1 = sys.argv[1]\nnumber_file_path2 = sys.argv[2]\nnumber_file_path3 = sys.argv[3]\nout_file_path = sys.argv[4]\n\ndef readFile(file_path):\n    with open(file_path) as number_file:\n      return float(number_file.read().rstrip())\n\nnumber1 = readFile(number_file_path1)\nnumber2 = readFile(number_file_path2)\nnumber3 = readFile(number_file_path3)\n\ntotal = number1 + number2 + number3\n\nwith open(out_file_path, 'w') as out_file:\n    out_file.write(str(total))"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1964",
                    "secondaryFiles": [
                        {
                            "pattern": ".c",
                            "required": null
                        },
                        {
                            "pattern": ".d",
                            "required": null
                        }
                    ],
                    "doc": "A file that contains a number in it.",
                    "id": "#sum_files_tool.cwl/number_file"
                },
                {
                    "type": "string",
                    "doc": "An output file that stores the summed value.\n#Output_File=format: edam:format_1964",
                    "id": "#sum_files_tool.cwl/output_file"
                }
            ],
            "arguments": [
                {
                    "shellQuote": false,
                    "valueFrom": "python sum.py $(inputs.number_file.path) $(inputs.number_file.path).c $(inputs.number_file.path).d $(inputs.output_file)\n\n#python sum.py $(inputs.number_file.path) $(inputs.number_file.path).a $(inputs.number_file.path).b $(inputs.output_file)"
                }
            ],
            "outputs": [
                {
                    "$import": "#sum_files_tool.cwl/output_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1964",
                    "id": "#sum_files_tool.cwl/standard_error",
                    "outputBinding": {
                        "glob": "stderr.txt"
                    }
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1964",
                    "id": "#sum_files_tool.cwl/standard_output",
                    "outputBinding": {
                        "glob": "stdout.txt"
                    }
                }
            ],
            "stdout": "stdout.txt",
            "stderr": "stderr.txt",
            "id": "#sum_files_tool.cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/name": "Stephen Piccolo",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-2001-5640"
                }
            ],
            "https://schema.org/dateCreated": "2021-03-29",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0"
        }
    ],
    "cwlVersion": "v1.2",
    "$schemas": [
        "https://schema.org/version/latest/schemaorg-current-http.rdf",
        "http://edamontology.org/EDAM_1.23.owl"
    ],
    "$namespaces": {
        "s": "https://schema.org/",
        "edam": "http://edamontology.org/"
    }
}
